@@ -5,12 +5,13 @@ GC_VCS_P_CFG = "vcs_p.json"
 GC_SRC_NAME = "../src"
 GC_REPOS_NAME = ".repos"
 GC_DEFAULT_BRANCH_NAME = "master"
-GC_DEFAULT_PROFILE_NAME = "default"
 GC_COMMIT_FILE_NAME = "_commit.vcs_p"
 GC_EDITOR_COMMIT_DEFAULT = "nano"
 GC_DOCKER_OPEN_CMD = "docker run --rm -it -v $(pwd):/ws -w /ws 192.168.89.202:5000/promobot/pm_meta:latest"
 
-G_CFG = {"repos": [], "profile": "default", "profiles": {}}
+G_CFG = {}
+G_CFG["repos"] = []
+G_CFG["profiles"] = {}
 
 gp_profile = None
 
